package user

import (
	"github.com/gin-gonic/gin"
	"hongze/hongze_yb/controller/response"
	"hongze/hongze_yb/models/request/user"
	userResp "hongze/hongze_yb/models/response/user"
	userService "hongze/hongze_yb/services/user"
	"hongze/hongze_yb/utils"
	"strings"
)

// Login 登录接口
// @Tags 用户模块
// @Summary  用户登录
// @Description 用户手机号/邮箱登录
// @Security ApiKeyAuth
// @Param Authorization	header string true "Bearer 31a165baebe6dec616b1f8f3207b4273"
// @Accept  json
// @Product json
// @Param	request	body user.LoginReq true "type json string"
// @Success 200 {object}	user.LoginResp
// @Router /user/login [post]
func Login(c *gin.Context) {
	var req user.LoginReq
	if c.ShouldBind(&req) != nil {
		response.Fail("参数异常", c)
		return
	}
	userInfo := userService.GetInfoByClaims(c)

	openId := userInfo.OpenID
	if openId == "" {
		response.Fail("参数异常", c)
		return
	}
	if req.LoginType == 1 {
		//手机登录
		if req.Mobile == "" {
			response.Fail("手机号不能为空,请输入手机号", c)
			return
		}
		req.Mobile = strings.Trim(req.Mobile, " ")
	} else if req.LoginType == 2 {
		//邮箱登录
		if req.Email == "" {
			response.Fail("邮箱不能为空,请输入邮箱", c)
			return
		}
		if !utils.ValidateEmailFormatat(req.Email) {
			response.Fail("邮箱格式错误，请重新输入", c)
			return
		}
	} else {
		response.Fail("无效的登录方式", c)
		return
	}
	token, newUserInfo, err, errMsg := userService.BindWxUser(openId, req.Mobile, req.Email, req.VerifyCode, req.LoginType, req.AreaNum, 1)
	if err != nil {
		if errMsg != "" {
			errMsg = "登录失败"
		}
		response.Fail(errMsg, c)
		return
	}

	response.OkData("登录成功", userResp.LoginResp{
		UserID: int(newUserInfo.UserID),
		Token:  token,
		Email:  newUserInfo.Email,
		Mobile: newUserInfo.Mobile,
	}, c)
}

//func  GetEmailCode() {
//	br := new(models.BaseResponse).Init()
//	defer func() {
//		this.Data["json"] = br
//		this.ServeJSON()
//	}()
//	email := this.GetString("Email")
//	if email == "" {
//		br.Msg = "请输入邮箱地址"
//		return
//	}
//	if !utils.ValidateEmailFormatat(email) {
//		br.Msg = "邮箱格式错误，请重新输入"
//		return
//	}
//	msgCode := utils.GetRandDigit(4)
//	content := "尊敬的用户：</br>您好，感谢您使用弘则研究，您正在进行邮箱验证，本次请求的验证码为：" + msgCode + "（为了保障您账号的安全性，请在15分钟内完成验证。）</br>弘则研究团队 </br>2019年05月11日"
//	title := "弘则研究登陆验证"
//	//发送邮件
//	result, err := utils.SendEmailByHz(title, content, email)
//	if err != nil {
//		br.Msg = "发送失败"
//		br.ErrMsg = "发送失败,Err:" + err.Error()
//		return
//	}
//	if result {
//		item := new(models.MsgCode)
//		item.OpenId = ""
//		item.Code = msgCode
//		item.Mobile = email
//		item.ExpiredIn = time.Now().Add(15 * time.Minute).Unix()
//		item.Enabled = 1
//		item.CreatedTime = time.Now()
//		err := models.AddMsgCode(item)
//		if err != nil {
//			br.Msg = "发送失败"
//			br.ErrMsg = "发送失败，Err:" + err.Error()
//			return
//		}
//		br.Msg = "发送成功"
//	} else {
//		br.Msg = "发送失败"
//	}
//	br.Ret = 200
//	br.Success = true
//}
//
//func GetSmsCode() {
//	br := new(models.BaseResponse).Init()
//	defer func() {
//		this.Data["json"] = br
//		this.ServeJSON()
//	}()
//	mobile := this.GetString("Mobile")
//	if mobile == "" {
//		br.Msg = "请输入手机号"
//		return
//	}
//	areaNum := this.GetString("AreaNum")
//	msgCode := utils.GetRandDigit(4)
//	var result bool
//	if areaNum == "86" || areaNum == "" || areaNum == "0" {
//		result = services.SendSmsCode(mobile, msgCode)
//	} else {
//		result = services.SendSmsCodeGj(mobile, msgCode, areaNum)
//	}
//	//发送成功
//	if result {
//		item := new(models.MsgCode)
//		item.OpenId = ""
//		item.Code = msgCode
//		item.Mobile = mobile
//		item.ExpiredIn = time.Now().Add(15 * time.Minute).Unix()
//		item.Enabled = 1
//		item.CreatedTime = time.Now()
//		err := models.AddMsgCode(item)
//		if err != nil {
//			br.Msg = "发送失败"
//			br.ErrMsg = "发送失败，Err:" + err.Error()
//			return
//		}
//		br.Msg = "发送成功"
//	} else {
//		br.Msg = "发送失败"
//	}
//	br.Ret = 200
//	br.Success = true
//}
