package middleware

import (
	"fmt"
	"github.com/gin-gonic/gin"
	"hongze/hongze_yb/controller/response"
	"hongze/hongze_yb/global"
	"hongze/hongze_yb/utils"
	"net/http"
	"runtime"
	"time"
)

// Recover 异常处理
func Recover() gin.HandlerFunc {
	return func(c *gin.Context) {
		defer func() {
			if err := recover(); err != nil {
				stack := ""

				msg := fmt.Sprintf("The request url is  %v", c.Request.RequestURI)
				stack += msg + "</br>"
				global.LOG.Critical(msg)
				msg = fmt.Sprintf("The request data is %v", c.Params)
				stack += msg + "</br>"
				global.LOG.Critical(msg)
				msg = fmt.Sprintf("Handler crashed with error %v", err)
				stack += msg + "</br>"
				global.LOG.Critical(msg)
				for i := 1; ; i++ {
					_, file, line, ok := runtime.Caller(i)
					if !ok {
						break
					}
					global.LOG.Critical(fmt.Sprintf("%s:%d", file, line))
					stack = stack + fmt.Sprintln(fmt.Sprintf("%s:%d</br>", file, line))
				}
				fmt.Println("stack:", stack)
				response.Custom(http.StatusInternalServerError, "系统异常", c)
				//c.JSON(http.StatusInternalServerError, Err)
				go utils.SendEmail(utils.APPNAME+"崩了"+time.Now().Format("2006-01-02 15:04:05"), stack, utils.EmailSendToUsers)
				return
			}
		}()
		c.Next()
	}
}
